jQuery UI Tooltip - Custom animation demo

Tooltips can be attached to any element. When you hover the element with your mouse, the title attribute is displayed in a little box next to the element, just like a native tooltip.

But as it's not a native tooltip, it can be styled. Any themes built with ThemeRoller will also style tooltip's accordingly.

Tooltip's are also useful for form elements, to show some additional information in the context of each field.

Your age:

Click the field to see the tooltip; when you tab out of the field, it gets hidden.

Here the tooltips are positioned relative to the mouse, and follow the mouse while it moves above the element.